@@ -249,6 +249,7 @@ class SlurmProvisioner(KernelProvisionerBase):
             "nodelist": [],
             "endtime": None,
             "config": kernel_config,
+            "state": "PENDING"
         }
         self.write_local_storage_file(alloc_dict)
 
@@ -271,14 +272,9 @@ class SlurmProvisioner(KernelProvisionerBase):
 
         # Add Slurm-JobID with it's nodelist to local user storage file
         alloc_dict = self.read_local_storage_file()
-        alloc_dict[self.alloc_id] = {
-            "kernel_ids": [self.kernel_id],
-            "nodelist": self.alloc_listnode,
-            "endtime": (
-                datetime.now() + timedelta(minutes=int(kernel_config["runtime"]))
-            ).timestamp(),
-            "config": kernel_config,
-        }
+        alloc_dict[self.alloc_id]["nodelist"] = self.alloc_listnode
+        alloc_dict[self.alloc_id]["endtime"] = datetime.now() + timedelta(minutes=int(kernel_config["runtime"]))
+        alloc_dict[self.alloc_id]["pid"] = None
         self.write_local_storage_file(alloc_dict)
 
     async def pre_launch(self, **kwargs: Any) -> Dict[str, Any]:
